@@ -6,10 +6,10 @@ import pytest
 import yaml
 from loguru import logger
 
-from __init__ import __version__, __description__, __image__
-from scaffold import init_parser_scaffold, main_scaffold
-from make import init_make_parser, main_make
-from make_testcase import init_make_case_parser, main_make_case
+from aomaker import __version__, __description__, __image__
+from aomaker.scaffold import init_parser_scaffold, main_scaffold
+from aomaker.make import init_make_parser, main_make
+from aomaker.make_testcase import init_make_case_parser, main_make_case
 
 
 def init_parser_run(subparsers):
